@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 import sys
 import os
+import cPickle
 
 from gargoyle_launcher_gui import *
 
@@ -15,10 +16,13 @@ class GLaunch(QtGui.QMainWindow):
         self.setup_settings()
         #connect buttons
         QtCore.QObject.connect(self.ui.pushButtonBrowse, QtCore.SIGNAL('clicked()'), self.doBrowse)
+        QtCore.QObject.connect(self.ui.pushButtonAddGame, QtCore.SIGNAL('clicked()'), self.doAddGame)
+        QtCore.QObject.connect(self.ui.pushButtonDelete, QtCore.SIGNAL('clicked()'), self.doDelGame)
         QtCore.QObject.connect(self.ui.pushButtonLaunch, QtCore.SIGNAL('clicked()'), self.doLaunch)
 
+
         try:                                
-            self.ui.lineEditPath.setText(sys.argv[2])
+            self.ui.lineEditPath.setText(sys.argv[1])
         except:          
             print "no arguments"
             self.load_settings()
@@ -34,13 +38,27 @@ class GLaunch(QtGui.QMainWindow):
         self.ui.lineEditPath.setText(self.fileName)
 
     def doLaunch(self):
-        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle " + str(self.ui.lineEditPath.text()) + " &")
-        self.settings.setValue("last_path", self.ui.lineEditPath.text())
-        self.settings.setValue("close_on_exit", self.ui.checkBoxShutdown.isChecked())
+#        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle " + str(self.ui.lineEditPath.text()) + " &")
+#        self.settings.setValue("last_path", self.ui.lineEditPath.text())
+#        self.settings.setValue("close_on_exit", self.ui.checkBoxShutdown.isChecked())
+        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle " 
+                        + str(self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()) 
+                        + " &")
         if(self.ui.checkBoxShutdown.isChecked()):
             self.close()
 
 
+    def doAddGame(self):
+        add = 1
+        for i in range(self.ui.listWidgetGames.count()): #let's not create duplicates, so lets do a search.
+            if self.ui.listWidgetGames.item(i).text() == self.ui.lineEditPath.text():
+                add = 0
+        if add: #Okay, it wasn't found.  Let's add it.
+            self.ui.listWidgetGames.addItem(self.ui.lineEditPath.text())
+
+    def doDelGame(self):
+        self.ui.listWidgetGames.takeItem(self.ui.listWidgetGames.currentRow())
+
     def setup_settings(self):
         settings = QtCore.QSettings()
         QtCore.QCoreApplication.setOrganizationName('gman.me.uk')
@@ -53,10 +71,30 @@ class GLaunch(QtGui.QMainWindow):
             self.ui.lineEditPath.setText(str(self.settings.value("last_path").toString()))
             self.closeOnExit = self.settings.value("close_on_exit").toBool()
             print str(self.settings.value("last_path").toString())
+
+            games_list = cPickle.loads(str(self.settings.value("games_list").toString()))
+            for path in games_list:
+                 self.ui.listWidgetGames.addItem(path)
+            
+
         except:
             print "firstRun... no Savefile found"
             self.ui.lineEditPath.setText("/home/user/MyDocs/.documents/")
+
+
+    def closeEvent(self, event):
+        print "closing"        
+        self.settings.setValue("last_path", self.ui.lineEditPath.text())
+        self.settings.setValue("close_on_exit", self.ui.checkBoxShutdown.isChecked())
         
+        items = []
+        for index in xrange(self.ui.listWidgetGames.count()):
+            items.append(self.ui.listWidgetGames.item(index).text())
+
+        saveData = cPickle.dumps(items)
+        self.settings.setValue("games_list", saveData)
+
+
 
 if __name__ == "__main__":
     #This function means this was run directly, not called from another python file.
